==> xld-docker-plugin-6.2.0.jar: xlddocker/create_container.py <==
#
from xlddocker import connect_to_docker
dkr = connect_to_docker(deployed.container)

container_name = deployed.containerName or deployed.name
print "Creating container", container_name, "from image", deployed.image

volumes = []
binds = {}
for volume_binding in deployed.volumeBindings:
    volume_name = volume_binding.volumeName or volume_binding.name
    mountpoint = volume_binding.mountpoint
    mode = 'ro' if volume_binding.readOnly else 'rw'
    volumes.append(mountpoint)
    binds[volume_name] = { 'bind': mountpoint, 'mode': mode }

ports = []
port_bindings = {}
for port_binding in deployed.portBindings:
    container_port = port_binding.containerPort
    host_port = port_binding.hostPort
    protocol = port_binding.protocol
    if protocol != 'tcp':
        ports.append((container_port, str(protocol)))
        port_bindings[str(container_port) + '/' + str(protocol)] = host_port
    else:
        ports.append(container_port)
        port_bindings[container_port] = host_port

restart_policy = None
if deployed.restartPolicyName and deployed.restartPolicyName != 'none':
    restart_policy = {'Name': deployed.restartPolicyName, 'MaximumRetryCount': deployed.restartPolicyMaximumRetryCount}

host_config = dkr.api.create_host_config(
        binds=binds,
        dns_opt=deployed.dnsOptions,
        links=deployed.links,
        mem_limit=deployed.memoryLimit,
        pid_mode=deployed.pidMode,
        port_bindings=port_bindings,
        privileged=deployed.privileged,
        publish_all_ports=deployed.publishAllPorts,
        restart_policy=restart_policy)
container = dkr.api.create_container(
        name=container_name,
        image=deployed.image,
        command=deployed.command,
        domainname=deployed.domainname,
        detach=True,
        entrypoint=deployed.entrypoint,
        environment=deployed.environment,
        host_config=host_config,
        hostname=deployed.hostname,
        labels=deployed.labels,
        ports=ports,
        tty=deployed.tty,
        volumes=volumes,
        working_dir=deployed.workingDir)

deployed.containerId = container['Id']
print "Container has been created with ID", deployed.containerId

==> xld-docker-plugin-7.0.0.jar: xlddocker/create_container.py <==
#
from xlddocker import connect_to_docker
dkr = connect_to_docker(deployed.container)

container_name = deployed.containerName or deployed.name
print "Creating container", container_name, "from image", deployed.image

volumes = []
binds = {}
for volume_binding in deployed.volumeBindings:
    volume_name = volume_binding.volumeName or volume_binding.name
    mountpoint = volume_binding.mountpoint
    mode = 'ro' if volume_binding.readOnly else 'rw'
    volumes.append(mountpoint)
    binds[volume_name] = { 'bind': mountpoint, 'mode': mode }

ports = []
port_bindings = {}
for port_binding in deployed.portBindings:
    container_port = port_binding.containerPort
    host_port = port_binding.hostPort
    protocol = port_binding.protocol
    if protocol != 'tcp':
        ports.append((container_port, str(protocol)))
        port_bindings[str(container_port) + '/' + str(protocol)] = host_port
    else:
        ports.append(container_port)
        port_bindings[container_port] = host_port

restart_policy = None
if deployed.restartPolicyName and deployed.restartPolicyName != 'none':
    restart_policy = {'Name': deployed.restartPolicyName, 'MaximumRetryCount': deployed.restartPolicyMaximumRetryCount}

network_mode = "bridge"
if deployed.networks:
    network_mode = deployed.networks[0]

host_config = dkr.api.create_host_config(
        binds=binds,
        dns_opt=deployed.dnsOptions,
        links=deployed.links,
        mem_limit=deployed.memoryLimit,
        network_mode=network_mode,
        pid_mode=deployed.pidMode,
        port_bindings=port_bindings,
        privileged=deployed.privileged,
        publish_all_ports=deployed.publishAllPorts,
        restart_policy=restart_policy)

container = dkr.api.create_container(
        name=container_name,
        image=deployed.image,
        command=deployed.command,
        domainname=deployed.domainname,
        detach=True,
        entrypoint=deployed.entrypoint,
        environment=deployed.environment,
        host_config=host_config,
        hostname=deployed.hostname,
        labels=deployed.labels,
        ports=ports,
        tty=deployed.tty,
        volumes=volumes,
        working_dir=deployed.workingDir)

deployed.containerId = container['Id']
print "Container has been created with ID", deployed.containerId
